#ifndef QUADREX200_H
#define QUADREX200_H

#include <QWidget>
#include <QtGui>

#include <qextserialport.h> // gestion des connexions RS232

#include "ui_quadrex200.h" // interface graphique
#include "fenetre_rs232.h" // fenetre de configuration RS232
#include "fenetre_parametres.h" // fenetre de configuration de la mesure

class QUADREX200 : public QMainWindow
{
  Q_OBJECT

// variables et fonctions
public:
  QUADREX200(QWidget *parent = 0); // constructeur

  Ui::QUADREX200 ui; // interface graphique principale



  int connexion(void); // permet de se connecter a l'appareil
  void deconnexion(void); // permet de se deconnecter de l'appareil

  // fonctions de envoi et reception
  int send_rs232(QString la_commande); // envoyer vers l'appareil
  QString receive_rs232(void); // recevoir une ligne de l'appareil
  void vider_rs232(void); // recevoir une ligne de l'appareil

  // fonctions
  void donneheure(void); // affiche l'heure et la date de la mesure
  void donnenomfichier(void); // donne le nom du fichier
  void traitementdonnnees(QString texte, int massecentrale, QString gain); // lectures des mesures en memoire sur l'appareil

  // variables
  QDateTime date_init; // heure de debut
  QString date_du_jour; // date annee/mois/jour de debut
  QString nom_fichier; // nom du fichier
  QextSerialPort *port; // sert a communiquer par le port serie
  QTextStream out; // sert a l'enregistrement du fichier

  // ouverture des fenetres
  RS232 fenetre_rs232; // fenetre pour configurer la connexion RS232
  PARAMETRES fenetre_parametres; // fenetre pour configurer la mesure

  // les elements du UI
  public slots:
  void on_pushButton_1_1_clicked();  // configuration RS232
  void on_pushButton_1_2_clicked();  // configuration paramtres
  void on_pushButton_1_3_clicked();  // connexion a l'appareil

  // les fonctions de dialogue
  QString choixparametre(QString lettre);
  // selection gain de l'affichage analogique <STX>/P/0/<TRM>
  // selection de la vitesse de balayage STx/P/1/TRM
  // selection du centre de la masse <STX>/P/3/<TRM>
  // selection de la largeur de l'affichage <STx>/P/4/<TRM>

  QString lectureparametre(void); // <STX>/F/<TRM>


  QString reciproque(void); // indicateur de donnees reciproques  ==> STX/A/TRM
  QString index(int index_min, int index_max); // delimitation de l'index pour les mesures ==> STX/I/1ere valeur d'index/dlimiteur/2e valeur d'index/TRM
  QString indicateurreciproque(void); // indicateur de donnees reciproques - mode analogique ==> STX/D/1/TRM
  QString getvaleurs(void); // lectures des mesures en memoire sur l'appareil ==> STX/G/TRM



};

#endif
